/**
 * Call all the registered handlers for the given event name with the given arguments
 *
 * @param {string} name of the event
 * @param {any[]} arguments to be passed to the handlers
 */
export declare function fireEvent(name: string, ...args: any[]): void;
/**
 * Removes a given event from events registered
 *
 * @param {string} name of the event to remove
 */
export declare function removeEvent(eventName: string): void;
/**
 * Registers the given listener for the given event
 *
 * @param {string} Name of event
 * @param {Function} listener to be registered
 * @param {boolean} if parameter once set to `true` calls this listener only the first time the given event is fired
 */
export declare function registerEventListener(eventName: string, listener: Function, once?: boolean): void;
export declare const EventBus: {
    $emit: typeof fireEvent;
    $off: typeof removeEvent;
    $on: typeof registerEventListener;
};
