import type { Auth, ActionCodeSettings, User, UserCredential, AuthProvider, PopupRedirectResolver, AuthCredential, ErrorFn, CompleteFn, NextOrObserver, OAuthCredential } from "firebase/auth";
import type { FirebaseApp, FirebaseOptions } from "firebase/app";
declare type Provider = "google" | "facebook" | "github";
interface UpdateProfilePayload {
    displayName?: string | null;
    photoURL?: string | null;
}
/**
 * Makes firebase calls active i.e all calls will only start resolving
 * after this function is called
 * * Also the function isn't expected to be called more than once
 */
export declare const makeFirebaseActive: (config: FirebaseOptions) => void;
/**
 * Makes firebase calls active i.e all calls will only start resolving
 * after this function is called
 * * Also the function isn't expected to be called more than once
 */
export declare const makeAnalyticsActive: () => void;
/**
 * Returns the Auth instance associated with the provided {@link @firebase/app#FirebaseApp}.
 * If no instance exists, initializes an Auth instance with platform-specific default dependencies.
 *
 * @param {FirebaseApp} - The Firebase App.
 * @returns {Promise<Auth>} A Promise to the firebase auth module
 *
 */
export declare function getAuth(app?: FirebaseApp): Promise<Auth>;
/**
 *
 * @param {string} provider the name of provider {google, facebook, github}
 * @returns this function returns AuthProvider/Credential instance
 */
export declare function getProvider(provider: Provider): Promise<AuthProvider>;
/**
 *
 * @param {Provider} provider the name of provider {google, facebook, github}
 * @param {string} accessToken return by new priveder
 * @returns this function returns AuthProvider/Credential instance
 */
export declare function getCredential(provider: Provider, accessToken: string): Promise<OAuthCredential>;
/**
 * Function gets the user data asynchronously
 *
 * @returns {User | null} - user data
 */
export declare function getCurrentUser(): Promise<User | null>;
/**
 * Function gets the user token
 *
 * @returns {Promise<string>} - user token
 */
export declare function getUserToken(): Promise<string>;
/**
 * Function get the user id
 *
 *  @returns {Promise<string>} - return the user id
 */
export declare function getUserId(): Promise<string | undefined>;
/**
 *
 * @logs production events in google analytics
 * refer : https://firebase.google.com/docs/analytics/events?platform=web#web-version-9_1
 * Refer the above link to know more about the syntax of firebase version 9
*/
export declare function analyticsLogger(logType: string, logObject: any): void;
export declare function sendPasswordResetEmail(email: string, actionCodeSettings?: ActionCodeSettings): Promise<void>;
export declare function fetchSignInMethodsForEmail(email: string): Promise<string[]>;
export declare function signInWithEmailAndPassword(email: string, password: string): Promise<UserCredential>;
export declare function createUserWithEmailAndPassword(email: string, password: string): Promise<UserCredential>;
export declare function sendEmailVerification(user: User, actionCodeSettings?: ActionCodeSettings | null): Promise<void>;
export declare function updateProfile(user: User, payload: UpdateProfilePayload): Promise<void>;
export declare function updateEmail(user: User, newEmail: string): Promise<void>;
export declare function signInWithPopup(provider: Provider, resolver?: PopupRedirectResolver): Promise<UserCredential>;
export declare function signInWithRedirect(provider: Provider, resolver?: PopupRedirectResolver): Promise<never>;
export declare function signOut(): Promise<never>;
export declare function linkWithCredential(user: User, credential: AuthCredential): Promise<UserCredential>;
export declare function linkWithAccessToken(user: User, provider: Provider, accessToken: string): Promise<UserCredential>;
export declare function linkWithRedirect(user: User, provider: AuthProvider, resolver?: PopupRedirectResolver): Promise<never>;
export declare function linkWithPopup(user: User, provider: AuthProvider, resolver?: PopupRedirectResolver): Promise<never>;
export declare function getRedirectResult(resolver?: PopupRedirectResolver): Promise<UserCredential | null>;
export declare function signInWithCredential(credential: AuthCredential): Promise<UserCredential>;
export declare function signInWithAccessToken(provider: Provider, accessToken: string): Promise<UserCredential>;
export declare function onAuthStateChanged(nextOrObserver: NextOrObserver<User>, error?: ErrorFn, completed?: CompleteFn): void;
export {};
